@@ -185,7 +185,6 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void setItemFetchScope( const ItemFetchScope &fetchScope );
 
-
     /**
      * Instructs the monitor to fetch only those parts that were changed and
      * were requested in the fetch scope.
@@ -268,7 +267,7 @@ class AKONADI_EXPORT Monitor : public QObject
      *
      * @deprecated Use itemsMonitoredEx() instead.
      */
-    KDE_DEPRECATED QList<Item::Id> itemsMonitored() const;
+    AKONADI_DEPRECATED QList<Item::Id> itemsMonitored() const;
 
     /**
      * Returns the set of items being monitored.
