@@ -236,7 +236,7 @@ class ResourceScheduler : public QObject
     void executeNext();
 
   private:
-    void signalTaskToTracker( const Task &task, const QByteArray &taskType );
+    void signalTaskToTracker( const Task &task, const QByteArray &taskType, const QString &debugString = QString() );
 
     // We have a number of task queues, by order of priority.
     // * ChangeReplay must be first:
