@@ -98,39 +98,39 @@ void LDAPProtocol::LDAPErr( int err )
   switch (err) {
 /* FIXME: is it worth mapping the following error codes to kio errors?
 
-	LDAP_OPERATIONS_ERROR
+  LDAP_OPERATIONS_ERROR
   LDAP_STRONG_AUTH_REQUIRED
-	LDAP_PROTOCOL_ERROR
-	LDAP_TIMELIMIT_EXCEEDED
-	LDAP_SIZELIMIT_EXCEEDED
-	LDAP_COMPARE_FALSE
-	LDAP_COMPARE_TRUE
-	LDAP_PARTIAL_RESULTS
-	LDAP_NO_SUCH_ATTRIBUTE
-	LDAP_UNDEFINED_TYPE
-	LDAP_INAPPROPRIATE_MATCHING
-	LDAP_CONSTRAINT_VIOLATION
-	LDAP_INVALID_SYNTAX
-	LDAP_NO_SUCH_OBJECT
-	LDAP_ALIAS_PROBLEM
-	LDAP_INVALID_DN_SYNTAX
-	LDAP_IS_LEAF
-	LDAP_ALIAS_DEREF_PROBLEM
-	LDAP_INAPPROPRIATE_AUTH
-	LDAP_BUSY
-	LDAP_UNAVAILABLE
-	LDAP_UNWILLING_TO_PERFORM
-	LDAP_LOOP_DETECT
-	LDAP_NAMING_VIOLATION
-	LDAP_OBJECT_CLASS_VIOLATION
-	LDAP_NOT_ALLOWED_ON_NONLEAF
-	LDAP_NOT_ALLOWED_ON_RDN
-	LDAP_NO_OBJECT_CLASS_MODS
-	LDAP_OTHER
-	LDAP_LOCAL_ERROR
-	LDAP_ENCODING_ERROR
-	LDAP_DECODING_ERROR
-	LDAP_FILTER_ERROR
+  LDAP_PROTOCOL_ERROR
+  LDAP_TIMELIMIT_EXCEEDED
+  LDAP_SIZELIMIT_EXCEEDED
+  LDAP_COMPARE_FALSE
+  LDAP_COMPARE_TRUE
+  LDAP_PARTIAL_RESULTS
+  LDAP_NO_SUCH_ATTRIBUTE
+  LDAP_UNDEFINED_TYPE
+  LDAP_INAPPROPRIATE_MATCHING
+  LDAP_CONSTRAINT_VIOLATION
+  LDAP_INVALID_SYNTAX
+  LDAP_NO_SUCH_OBJECT
+  LDAP_ALIAS_PROBLEM
+  LDAP_INVALID_DN_SYNTAX
+  LDAP_IS_LEAF
+  LDAP_ALIAS_DEREF_PROBLEM
+  LDAP_INAPPROPRIATE_AUTH
+  LDAP_BUSY
+  LDAP_UNAVAILABLE
+  LDAP_UNWILLING_TO_PERFORM
+  LDAP_LOOP_DETECT
+  LDAP_NAMING_VIOLATION
+  LDAP_OBJECT_CLASS_VIOLATION
+  LDAP_NOT_ALLOWED_ON_NONLEAF
+  LDAP_NOT_ALLOWED_ON_RDN
+  LDAP_NO_OBJECT_CLASS_MODS
+  LDAP_OTHER
+  LDAP_LOCAL_ERROR
+  LDAP_ENCODING_ERROR
+  LDAP_DECODING_ERROR
+  LDAP_FILTER_ERROR
 */
     case KLDAP_AUTH_UNKNOWN:
     case KLDAP_INVALID_CREDENTIALS:
@@ -297,10 +297,10 @@ void LDAPProtocol::openConnection()
   mConnected = true;
 
   AuthInfo info;
-  info.url.setProtocol( mProtocol );
+  info.url.setScheme( mProtocol );
   info.url.setHost( mServer.host() );
   info.url.setPort( mServer.port() );
-  info.url.setUser( mServer.user() );
+  info.url.setUserName( mServer.user() );
   info.caption = i18n("LDAP Login");
   info.comment = QString::fromLatin1( mProtocol ) + "://" + mServer.host() + ':' +
     QString::number( mServer.port() );
