@@ -39,41 +39,41 @@ QTEST_KDEMAIN( SignatureTester, GUI )
 void SignatureTester::testSignatures()
 {
   Signature sig1;
-  sig1.setText( "Hello World" );
-  QCOMPARE( sig1.text(), QString( "Hello World" ) );
+  sig1.setText( QLatin1String("Hello World") );
+  QCOMPARE( sig1.text(), QLatin1String( "Hello World" ) );
   QCOMPARE( sig1.type(), Signature::Inlined );
-  QCOMPARE( sig1.rawText(), QString( "Hello World" ) );
+  QCOMPARE( sig1.rawText(), QLatin1String( "Hello World" ) );
   QVERIFY( !sig1.isInlinedHtml() );
-  QCOMPARE( sig1.withSeparator(), QString( "-- \nHello World" ) );
+  QCOMPARE( sig1.withSeparator(), QLatin1String( "-- \nHello World" ) );
 
   Signature sig2;
-  sig2.setText( "<b>Hello</b> World" );
+  sig2.setText( QLatin1String("<b>Hello</b> World") );
   sig2.setInlinedHtml( true );
   QVERIFY( sig2.isInlinedHtml() );
   QCOMPARE( sig2.type(), Signature::Inlined );
-  QCOMPARE( sig2.rawText(), QString( "<b>Hello</b> World" ) );
-  QCOMPARE( sig2.withSeparator(), QString( "-- <br><b>Hello</b> World" ) );
+  QCOMPARE( sig2.rawText(), QLatin1String( "<b>Hello</b> World" ) );
+  QCOMPARE( sig2.withSeparator(), QLatin1String( "-- <br><b>Hello</b> World" ) );
 
   // Read this very file in, we use it for the tests
-  QFile thisFile( __FILE__ );
+  QFile thisFile( QLatin1String(__FILE__) );
   thisFile.open( QIODevice::ReadOnly );
   QString fileContent = QString::fromUtf8( thisFile.readAll() );
 
   Signature sig3;
-  sig3.setUrl( QString( "cat " ) + QString( __FILE__ ), true );
+  sig3.setUrl( QLatin1String( "cat " ) + QLatin1String( __FILE__ ), true );
   QCOMPARE( sig3.rawText(), fileContent );
   QVERIFY( !sig3.isInlinedHtml() );
   QVERIFY( sig3.text().isEmpty() );
   QCOMPARE( sig3.type(), Signature::FromCommand );
-  QCOMPARE( sig3.withSeparator(), QString( "-- \n" ) + fileContent );
+  QCOMPARE( sig3.withSeparator(), QLatin1String( "-- \n" ) + fileContent );
 
   Signature sig4;
-  sig4.setUrl( __FILE__, false );
+  sig4.setUrl( QLatin1String(__FILE__), false );
   QCOMPARE( sig4.rawText(), fileContent );
   QVERIFY( !sig4.isInlinedHtml() );
   QVERIFY( sig4.text().isEmpty() );
   QCOMPARE( sig4.type(), Signature::FromFile );
-  QCOMPARE( sig4.withSeparator(), QString( "-- \n" ) + fileContent );
+  QCOMPARE( sig4.withSeparator(), QLatin1String( "-- \n" ) + fileContent );
 }
 
 static void setCursorPos( QTextEdit &edit, int pos )
@@ -88,61 +88,61 @@ void SignatureTester::testTextEditInsertion()
   TextEdit edit;
   Signature sig;
   sig.setEnabledSignature( true );
-  sig.setText( "Hello World" );
+  sig.setText( QLatin1String("Hello World") );
 
   // Test inserting signature at start, with seperators
-  edit.setPlainText( "Bla Bla" );
+  edit.setPlainText( QLatin1String("Bla Bla") );
   sig.insertIntoTextEdit( Signature::Start, Signature::AddSeparator | Signature::AddNewLines,
                           &edit );
   QVERIFY( edit.textMode() == KRichTextEdit::Plain );
-  QCOMPARE( edit.toPlainText(), QString( "-- \nHello World\nBla Bla" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "-- \nHello World\nBla Bla" ) );
 
   // Test inserting signature at end. make sure cursor position is preserved
   edit.clear();
-  edit.setPlainText( "Bla Bla" );
+  edit.setPlainText( QLatin1String("Bla Bla") );
   setCursorPos( edit, 4 );
   sig.insertIntoTextEdit( Signature::End, Signature::AddSeparator | Signature::AddNewLines,
                           &edit );
-  QCOMPARE( edit.toPlainText(), QString( "Bla Bla\n-- \nHello World" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "Bla Bla\n-- \nHello World" ) );
   QCOMPARE( edit.textCursor().position(), 4 );
 
   // test inserting a signature at cursor position. make sure the signature is inserted
   // to the beginning of the line and make sure modified state is preserved
   edit.clear();
-  edit.setPlainText( "Bla Bla" );
+  edit.setPlainText( QLatin1String("Bla Bla") );
   setCursorPos( edit, 4 );
   edit.document()->setModified( false );
   sig.insertIntoTextEdit( Signature::AtCursor, Signature::AddSeparator | Signature::AddNewLines,
                           &edit );
-  QCOMPARE( edit.toPlainText(), QString( "-- \nHello World\nBla Bla" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "-- \nHello World\nBla Bla" ) );
   QCOMPARE( edit.textCursor().position(), 20 );
   QVERIFY( !edit.document()->isModified() );
 
   // make sure undo undoes everything in one go
   edit.undo();
-  QCOMPARE( edit.toPlainText(), QString( "Bla Bla" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "Bla Bla" ) );
 
   // test inserting signature without seperator.
   // make sure cursor position and modified state is preserved.
   edit.clear();
-  edit.setPlainText( "Bla Bla" );
+  edit.setPlainText( QLatin1String("Bla Bla") );
   setCursorPos( edit, 4 );
   edit.document()->setModified( true );
   sig.insertIntoTextEdit( Signature::End, Signature::AddNewLines, &edit );
-  QCOMPARE( edit.toPlainText(), QString( "Bla Bla\nHello World" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "Bla Bla\nHello World" ) );
   QCOMPARE( edit.textCursor().position(), 4 );
   QVERIFY( edit.document()->isModified() );
 
-  sig.setText( "Hello<br>World" );
+  sig.setText( QLatin1String("Hello<br>World") );
   sig.setInlinedHtml( true );
 
   // test that html signatures turn html on and have correct line endings (<br> vs \n)
   edit.clear();
-  edit.setPlainText( "Bla Bla" );
+  edit.setPlainText( QLatin1String("Bla Bla") );
   sig.insertIntoTextEdit( Signature::End, Signature::AddSeparator | Signature::AddNewLines,
                           &edit );
   QVERIFY( edit.textMode() == KRichTextEdit::Rich );
-  QCOMPARE( edit.toPlainText(), QString( "Bla Bla\n-- \nHello\nWorld" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "Bla Bla\n-- \nHello\nWorld" ) );
 }
 
 void SignatureTester::testBug167961()
@@ -150,7 +150,7 @@ void SignatureTester::testBug167961()
   TextEdit edit;
   Signature sig;
   sig.setEnabledSignature( true );
-  sig.setText( "BLA" );
+  sig.setText( QLatin1String("BLA") );
 
   // Test that the cursor is still at the start when appending a sig into
   // an empty text edit
@@ -179,8 +179,8 @@ void SignatureTester::testImages()
   QImage image1, image2;
   QVERIFY( image1.load( image1Path ) );
   QVERIFY( image2.load( image1Path ) );
-  QString path = KStandardDirs::locateLocal( "data", "emailidentities/unittest/" );
-  QString configPath = KStandardDirs::locateLocal( "config", "signaturetest" );
+  QString path = KStandardDirs::locateLocal( "data", QLatin1String("emailidentities/unittest/") );
+  QString configPath = KStandardDirs::locateLocal( "config", QLatin1String("signaturetest") );
   KConfig config( configPath );
   KConfigGroup group1 = config.group( "Signature1" );
 
@@ -188,32 +188,32 @@ void SignatureTester::testImages()
   sig.setEnabledSignature( true );
   sig.setImageLocation( path );
   sig.setInlinedHtml( true );
-  sig.setText( "Bla<img src=\"folder-new.png\">Bla" );
-  sig.addImage( image1, "folder-new.png" );
+  sig.setText( QLatin1String("Bla<img src=\"folder-new.png\">Bla") );
+  sig.addImage( image1, QLatin1String("folder-new.png") );
   sig.writeConfig( group1 );
 
   // OK, signature saved, the image should be saved as well
   QDir dir( path );
   QStringList entryList = dir.entryList( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks );
   QCOMPARE( entryList.count(), 1 );
-  QCOMPARE( entryList.first(), QString( "folder-new.png" ) );
+  QCOMPARE( entryList.first(), QLatin1String( "folder-new.png" ) );
 
   // Now, set the text of the signature to something without images, then save it.
   // The signature class should have removed the images.
-  sig.setText( "ascii ribbon campaign - against html mail" );
+  sig.setText( QLatin1String("ascii ribbon campaign - against html mail") );
   sig.writeConfig( group1 );
   entryList = dir.entryList( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks );
   QCOMPARE( entryList.count(), 0 );
 
   // Enable images again, this time with two of the buggers
-  sig.setText( "Bla<img src=\"folder-new.png\">Bla<img src=\"arrow-up.png\">Bla" );
-  sig.addImage( image1, "folder-new.png" );
-  sig.addImage( image2, "arrow-up.png" );
+  sig.setText( QLatin1String("Bla<img src=\"folder-new.png\">Bla<img src=\"arrow-up.png\">Bla") );
+  sig.addImage( image1, QLatin1String("folder-new.png") );
+  sig.addImage( image2, QLatin1String("arrow-up.png") );
   sig.writeConfig( group1 );
   entryList = dir.entryList( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks );
   QCOMPARE( entryList.count(), 2 );
-  QCOMPARE( entryList.first(), QString( "arrow-up.png" ) );
-  QCOMPARE( entryList.last(), QString( "folder-new.png" ) );
+  QCOMPARE( entryList.first(), QLatin1String( "arrow-up.png" ) );
+  QCOMPARE( entryList.last(), QLatin1String( "folder-new.png" ) );
 
   // Now, create a second signature instance from the same config, and make sure it can still
   // read the images, and it does not mess up
@@ -222,15 +222,15 @@ void SignatureTester::testImages()
   sig2.insertIntoTextEdit( KPIMIdentities::Signature::End, Signature::AddSeparator | Signature::AddNewLines,
                            &edit );
   QCOMPARE( edit.embeddedImages().count(), 2 );
-  QCOMPARE( sig2.text(), QString( "Bla<img src=\"folder-new.png\">Bla<img src=\"arrow-up.png\">Bla" ) );
+  QCOMPARE( sig2.text(), QLatin1String( "Bla<img src=\"folder-new.png\">Bla<img src=\"arrow-up.png\">Bla" ) );
   sig2.writeConfig( group1 );
   entryList = dir.entryList( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks );
   QCOMPARE( entryList.count(), 2 );
-  QCOMPARE( entryList.first(), QString( "arrow-up.png" ) );
-  QCOMPARE( entryList.last(), QString( "folder-new.png" ) );
+  QCOMPARE( entryList.first(), QLatin1String( "arrow-up.png" ) );
+  QCOMPARE( entryList.last(), QLatin1String( "folder-new.png" ) );
 
   // Remove one image from the signature, and make sure only 1 file is left one file system.
-  sig2.setText( "<img src=\"folder-new.png\">" );
+  sig2.setText( QLatin1String("<img src=\"folder-new.png\">") );
   sig2.writeConfig( group1 );
   edit.clear();
   sig2.insertIntoTextEdit( Signature::End, Signature::AddSeparator | Signature::AddNewLines,
@@ -246,16 +246,16 @@ void SignatureTester::testLinebreaks()
   sig.setEnabledSignature( true );
   sig.setType( Signature::Inlined );
   sig.setInlinedHtml( true );
-  sig.setText( "Hans Mustermann<br>Musterstr. 42" );
+  sig.setText( QLatin1String("Hans Mustermann<br>Musterstr. 42") );
 
   KPIMTextEdit::TextEdit edit;
   sig.insertIntoTextEdit( Signature::Start, Signature::AddNothing, &edit );
-  QCOMPARE( edit.toPlainText(), QString( "Hans Mustermann\nMusterstr. 42" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "Hans Mustermann\nMusterstr. 42" ) );
 
   edit.clear();
-  sig.setText( "<p>Hans Mustermann</p><br>Musterstr. 42" );
+  sig.setText( QLatin1String("<p>Hans Mustermann</p><br>Musterstr. 42") );
   sig.insertIntoTextEdit( Signature::Start, Signature::AddSeparator, &edit );
   QEXPECT_FAIL( "", "This test is probably bogus, since Qt doesn't seem to produce HTML like this anymore.", Continue );
-  QCOMPARE( edit.toPlainText(), QString( "-- \nHans Mustermann\nMusterstr. 42" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "-- \nHans Mustermann\nMusterstr. 42" ) );
 }
 
